@@ -3,7 +3,7 @@
 import json
 import tornado.ioloop
 import tornado.web
-from wsdl import Soap
+from .wsdl import Soap
 
 class MainHandler(tornado.web.RequestHandler):
     config = {}
