@@ -2,8 +2,8 @@
 #coding=utf8
 import click
 import json
-from wsdl import WSDLService, wsdl_from_url
-from server import start_server
+from .wsdl import WSDLService, wsdl_from_url
+from .server import start_server
 
 EMPTY_SOAP_RESPONSE = """<?xml version="1.0" encoding="utf-8"?>
 <soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
